@@ -19,22 +19,20 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 #include "mimetypeutils.h"
-#include "mimetypeutils_p.moc"
+#include "mimetypeutils_p.h"
 
 // Qt
 #include <QApplication>
 #include <QStringList>
+#include <QDebug>
+#include <QUrl>
+#include <QMimeDatabase>
 
 // KDE
-#include <KApplication>
-#include <KDebug>
 #include <KFileItem>
 #include <KIO/Job>
 #include <KIO/JobClasses>
 #include <KIO/NetAccess>
-#include <KMimeType>
-#include <KUrl>
-
 #include <KImageIO>
 
 // Local
@@ -49,8 +47,8 @@ namespace MimeTypeUtils
 
 static inline QString resolveAlias(const QString& name)
 {
-    KMimeType::Ptr ptr = KMimeType::mimeType(name, KMimeType::ResolveAliases);
-    return ptr.isNull() ? name : ptr->name();
+    QMimeDatabase db;
+    return db.mimeTypeForName(name).name();
 }
 
 static void resolveAliasInList(QStringList* list)
@@ -119,35 +117,14 @@ const QStringList& imageMimeTypes()
     return list;
 }
 
-QString urlMimeType(const KUrl& url)
+QString urlMimeType(const QUrl &url)
 {
     if (url.isEmpty()) {
         return "unknown";
     }
-    // Try a simple guess, using extension for remote urls
-    QString mimeType = KMimeType::findByUrl(url)->name();
-    if (mimeType == "application/octet-stream") {
-        kDebug() << "KMimeType::findByUrl() failed to find mimetype for" << url << ". Falling back to KIO::NetAccess::mimetype().";
-        // No luck, look deeper. This can happens with http urls if the filename
-        // does not provide any extension.
-        mimeType = KIO::NetAccess::mimetype(url, KApplication::kApplication()->activeWindow());
-    }
-    return mimeType;
-}
 
-QString urlMimeTypeByContent(const KUrl& url)
-{
-    const int HEADER_SIZE = 30;
-    if (url.isLocalFile()) {
-        return KMimeType::findByFileContent(url.toLocalFile())->name();
-    }
-
-    KIO::TransferJob* job = KIO::get(url);
-    DataAccumulator accumulator(job);
-    while (!accumulator.finished() && accumulator.data().size() < HEADER_SIZE) {
-        qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
-    }
-    return KMimeType::findByContent(accumulator.data())->name();
+    QMimeDatabase db;
+    return db.mimeTypeForUrl(url).name();
 }
 
 Kind mimeTypeKind(const QString& mimeType)
@@ -177,7 +154,7 @@ Kind fileItemKind(const KFileItem& item)
     return mimeTypeKind(item.mimetype());
 }
 
-Kind urlKind(const KUrl& url)
+Kind urlKind(const QUrl &url)
 {
     return mimeTypeKind(urlMimeType(url));
 }
